@@ -1,6 +1,6 @@
 /*
  *   zsync - client side rsync over http
- *   Copyright (C) 2004,2005 Colin Phipps <cph@moria.org.uk>
+ *   Copyright (C) 2004,2005,2007,2009 Colin Phipps <cph@moria.org.uk>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the Artistic License v2 (see the accompanying 
@@ -13,7 +13,7 @@
  *   COPYING file for details.
  */
 
-#include "config.h"
+#include "zsglobal.h"
 
 struct gzblock {
   uint16_t inbitoffset;
@@ -39,7 +39,7 @@ void configure_zstream_for_zdata(const struct zmap* zm, struct z_stream_s* zs, l
 #define GZ_COMMENT      0x10 /* bit 4 set: file comment present */
 #define GZ_RESERVED     0xE0 /* bits 5..7: reserved */
 
-static inline char* skip_zhead(char* p)
+static inline const char* skip_zhead(const char* p)
 {
   int flags = p[3];
   
